#################################################################################
#
#  Licensed Materials - Property of IBM
#  Restricted Material of IBM
#  IBM Rational Test RealTime
#  (c) Copyright IBM Corp. 2003-2014 All Rights Reserved.
#
#  US Governement Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
#################################################################################

##########################################################################
#                                                                        # #
# Rational Test RealTime                                                 #   #
#                                                                        #######
#                      -*-  Traces Splitter Script  -*-                        #
#                                                                              #
#                                                                              #
#  This script splits the traces file produced by tester / instrumented        #
#  application into components-specific traces files.                          #
#                                                                              #
#                                                                              #
# Required global variables:                                                   #
#   $LOGFILENAME   : name of the log file to generate.                         #
#   $NAME          : name of test node (used as a prefix for traces files)     #
#   $ATxMODE       : use x component                                           #
#                                                                              #
################################################################################
#$Id: Split.pl,v 1.100.4.15 2011/05/04 11:50:48 rfrance Exp $
################################################################################

require $SCRIPTDIR . "rtErrors.pl";

# Kinds of output files
$tdf = 1;
$tio = 2;
$rio = 3;
$tpf = 4;
$tqf = 5;
$undefined = 7;

@log_codes = ("ERR", "TDF", "TIO", "RIO", "TPF", "TQF");
@ext = ("err", "tdf", "tio", "rio", "tpf", "tqf");
@used = (0, 0, 0, 0, 0, 0);

$tdf_file_mode = "w";

# Return the file type matching an opcode
sub GetOpcodeProduct
{
  my $code=shift;
  return $tio if(index(",TB,TP,TE,FT,DC,NT,DT,TA,CO,EI",$code)>0) ;
  return $tpf if($code=~m/^P[FEBOUTSYX]/) ;
  return $tdf if($code=~m/^M[ERCS]/) ;
  return $tdf if($code=~m/^T[MISUX]/);
  return $tdf if($code=~m/^S[IOAFTY]/);
  return $tdf if(index(",CS,CI,HS,AC,BA,DB,DI,EA,ED,GL,ID,IN,LE,LK,LS,NI,NO,OT,US",$code)>0);
  return $tqf if($code=~m/^Q[FSUTD]/) ;
return 0;
}

# Split $traces_file
sub ExecSplit #($$)
{
  my ($traces_file, $print_warnings) = @_;

  my $product = 0;
  my $line = 0;
  my $FTline;
  my $warning_printed = 0;
  my $rejected = "atlout.rej";
  my $text = "";
  my $today = GetDate();
  my $endOfFileFound=0;

  if($ENV{ATL_SPLIT_CHECK})
  {
  my $status=0;
  my $tdpEndLine=0;
  my $covState=0;
  my $covCO=0;
  my $lineStatus=0;
      if(open (TRACES, "<$traces_file"))
      {
	  while(<TRACES>)
	  {
	    $text = $_;
	    chomp($text);
	    $line++;

	    if (/^([A-Z][A-Z])( .*)?/ &&
		($product = GetOpcodeProduct ($1)))
	    {
	      if($product == $tio)
	      {
		  if(/^T[ABPE]/) {
			if($covState!=3) { $lineStatus=2; $covState=3;}
			if($covCO){
			    $lineStatus=1 unless(/^T[ABPE]\s[0-9a-f]+\s[0-9a-f]+$/);
			} else {
			    $lineStatus=1 unless(/^T[ABPE] [0-9a-f]+$/);
			}
		  }elsif(/^FT/) {
			$lineStatus=1 unless(/FT [0-9a-f]{1,8}$/);
			$lineStatus=2 unless($covState & 1); # only 0 and 2
			$covState= 2;
		  }elsif (/^DC/){
			$lineStatus=1 unless(/DC [0-9a-f]{1,8}$/);
			$lineStatus=2 if($covState!=2);
			$covState= 3;
		  }elsif (/^NT/){
		  	$covCO=0;
		  	$lineStatus=1 unless(/^NT$|^NT\s(\"[^\"]*\")((\s[0-9a-fA-F]+)?(\s[0-9a-fA-F]+)?)$/);
			$lineStatus=2 if($covState==2);
		  	$covState=1;
		  }elsif (/^DT/){
		  	$lineStatus=1 unless(/^DT 0$|^DT\s(\"[^\"]*\")$/);
		  }elsif (/^CO/){
		  	$covCO=1;
		  }elsif (/^EI/){
				$status=1;
			print "ERROR: $_ \n";
		  }
	      }
	    }
	    elsif (/^I[0-9] /)
	    {
	    }
	    elsif (/^[A-FGHJ-ORTV-Z][0-9]+.*$/)
	    {
	      if(/^D[0-4] -/) {print &PerlTranslate("Split.pl", "Execution Time cannot be negative: mesure ingnored line %1 of %2\n", "",$line,$traces_file);next;}
	    }
	    elsif (/^[A-FGHJ-ORTV-Z]\([0-9A-F]*\}\s.*$/) #{ balance for editor
	    {
	    }
	    else
	    {
	      if(/^tdp end/) {$tdpEndLine=1;next;}
	      elsif(/^tdp/) {next;} #opcode used by TDP, line suppressed
	      elsif(/^WA\s*(.)(.*)$/){
	      	$status=1;
	      		my $info=""; $info="($2)" if($2);
			print "Runtime Error: ",ATL_ERROR($1)," $info\n";
			next;
	      }
	      $status=1;
	      print &PerlTranslate("Split.pl", "%1:%2: unrecognized line (file %3 contains all the rejected lines)\n", "%1 is the file being split, %2 is the line number and %3 is name of the file to look into", $traces_file, $line, $rejected) if (!$warning_printed);
	      $warning_printed = 1;
	    }
	    if($lineStatus)
	    {
	    	my $errType="";
			$status=1;
			$errType="line format" if($lineStatus ==1);
			$errType="unexpected sequence" if($lineStatus ==2);
	    	print &PerlTranslate("Split.pl", "ERROR: %1 at line %2 of %3. \"%4\"\n","",$errType,$line,$traces_file,$text);
	    	$lineStatus=0;
	    }
	  }
	  close (TRACES);
	  unless($tdpEndLine)
	  {
	      $status=1;
	      print &PerlTranslate("Split.pl", "ERROR: end of Execution not found in %2\n", "",$traces_file);
	  }
      } else {
	      print &PerlTranslate("Split.pl", "unable to open the file %1\n", "", $traces_file);
	      $status=1;
      }
      if($status){
      	   print &PerlTranslate("Split.pl", "Error found in file %1  => file not split\n", "", $traces_file);
	   return $status;
      }
  }
  open (TRACES, "<$traces_file") || return 5;
  open (REJECTED, ">$rejected") || ($warning_printed = 0);
  $line = 0;
  while(<TRACES>)
  {
    $text = $_;
    $line++;

    if (/^([A-Z][A-Z])( .*)?/ &&
        ($product = GetOpcodeProduct ($1)))
    {
      if(/^(FT|DC|DT|PT|QD|QT|NT)/){
         if(/^FT/){
            $FTline= $_;
            next;
         }elsif (/^DC/){
            print { $handles[$product] } $FTline if ($opened[$product]);
         }elsif (/^([QN]T)\s*$/){
            $_= "$1 \"$ENV{ATL_TEST_NAME}\"\n" if($ENV{ATL_TEST_NAME});
         }elsif (/^PT\s*$/){
            $_= "PT \"$ENV{ATL_TEST_NAME}\" \"$today\"\n" if($ENV{ATL_TEST_NAME});
         }elsif (/^PT \"(.*)\"$/){
            $_= "PT \"$1\" \"$today\"\n";

         }elsif (/^(DT|QD) (0|\"\")$/){
            $_= "$1 \"$today\"\n";
         }
      }
      $used[$product] = 1;
      print { $handles[$product] } $_ if ($opened[$product]);
    }
    elsif ($ATVMODE &&
           /^I[0-9] /)
    {
      if(/^(I7 [0-9a-f]+ x -)[0-9a-f]/) {$_=$1;print &PerlTranslate("Split.pl", "Execution Time cannot be negative: mesure ingnored line %1\n", "",$line);}
      $used[$rio] = 1;
      print { $handles[$rio] } $_ if ($opened[$rio]);
    }
    elsif ($ATUMODE &&
           /^[A-FGHJ-ORTV-Z][0-9]+.*$/)
    {
      if(/^D[0-4] -/) {print &PerlTranslate("Split.pl", "Execution Time cannot be negative: mesure ingnored line %1\n", "",$line);next;}
      if (/^H0$/){
          $_= "H0 $today\n";
      }
      $used[$rio] = 1;
      print { $handles[$rio] } $_ if ($opened[$rio]);
    }
    elsif ($ATUMODE &&
           /^[A-FGHJ-ORTV-Z]\([0-9A-F]*\}\s/) #{ balance for editor
    {
      $used[$rio] = 1;
      print { $handles[$rio] } $_ if ($opened[$rio]);
    }
    elsif ($ATSMODE &&
           (/^[a-df-z][0-9]+.*$/ ||
            /^f[bt][0-9]+.*$/ ||
            /^i[c-e][0-9]+.*$/ ||
            /^sd[0-9]+.*$/ ||
            /^t[fn][0-9]+.*$/ ||
            /^ATTOL SystemTest .*$/))
    {
      if (/^h 0/) {
          $_= "h $today\n";
      }
      $used[$rio] = 1;
      print { $handles[$rio] } $_ if ($opened[$rio]);
    }
    else
    {
      if(/^tdp\s(.*)$/) {$endOfFileFound=1 if($1 eq "end"); next;} #opcode used by TDP, line suppressed
      if(/^WA\s*(.)(.*)$/){
	my $info=""; $info="($2)" if($2);
	print "Runtime Error: ",ATL_ERROR($1)," $info\n";
      	next;
      }

      print &PerlTranslate("Split.pl", "%1:%2: unrecognized line (file %3 contains all the rejected lines)\n", "%1 is the file being split, %2 is the line number and %3 is name of the file to look into", $traces_file, $line, $rejected) if (!$warning_printed);
      $warning_printed = 1;
      print REJECTED "$line:$text";
    }
  } # while
  close (REJECTED);
  if (!$warning_printed) {
    unlink ($rejected);
  } else {
    open ( LOG, ">>$LOGFILENAME" ) or die &PerlTranslate("Split.pl", "Cannot open log file.\n");
    print  LOG "DUM $rejected\n";
    close( LOG );
  }

  close (TRACES);
  print &PerlTranslate("Split.pl", "Result traces are not complete ($line lines), the application under test has SHUTDOWN DURING ITS EXECUTION\n", "") unless ($endOfFileFound || $ATSMODE);
  return 0;
}

sub OpenDestFile #($$$)
{
   my ($type, $name, $mode) = @_;

   $output_files[$type] = $name;
   $handles[$type] = FileHandle->new ();
   if ($mode eq "a") {
     if(($warningTooBigFile) && ((-s $name) >4500000)){ #4.5MB
        $warningTooBigFile=0;
        print &PerlTranslate("Split.pl", "\nThe result files are growing and might be difficult to show. we suggest to reset the results before the next execution (see the report viewer menu)\n\n", "");
     }
     open ($handles[$type], ">>$name")
       or die &PerlTranslate("Split.pl", "Cannot open destination file \"%1\".\n", "%1 is the name of the destination file", $name);
   } else {
     open ($handles[$type], ">$name")
       or die &PerlTranslate("Split.pl", "Cannot open destination file \"%1\".\n", "%1 is the name of the destination file", $name);
   }
   $opened[$type] = 1;
}

sub CloseDestFile #($)
{
   my $type = shift;

   if ($used[$type]) {
     close( $handles[$type] );
   }
}

sub SplitTraces #($)
{
   my $tracesfile = shift;

   print &PerlTranslate("Split.pl", "Splitting '%1' traces file...\n", "%1 is the name of the file to be split", $tracesfile);

   my $warnings = 0;
   my $filen = 0;
   my $product = 0;
   my $one_file = "";

   if ($ATOMODE || $ATKMODE || $ATTMODE && !$ATJMODE)
   {
     $filen++;
     $product = $tdf;
     $TDFFILE = $NAME.'.'.$ext[$tdf] unless($TDFFILE);
     $one_file = $TDFFILE;
   }
   if ($ATCMODE)
   {
     $filen++;
     $product = $tio;
     $ATC_TIO_NAME=$NAME.'.'.$ext[$tio] unless($ATC_TIO_NAME);
   }
   if ($ATUMODE || $ATVMODE || $ATSMODE)
   {
     $filen++;
     $product = $rio;
     if ($ATUMODE || $ATVMODE)
     {
	$RIOFILE = $NAME.'.'.$ext[$rio] unless ($RIOFILE);
     }
     elsif ($ATSMODE)
     {
	$RIOFILE = "$tracesfile.date";
     }
     $one_file = $RIOFILE;
   }
   if ($ATPMODE)
   {
     $filen++;
     $product = $tpf;
     $ATP_TPF_NAME=$NAME.'.'.$ext[$tpf] unless($ATP_TPF_NAME);
   }
   if ($ATQMODE)
   {
     $filen++;
     $product = $tqf;
     $ATQ_TQF_NAME=$NAME.'.'.$ext[$tqf] unless($ATQ_TQF_NAME);
   }

   #### generate LOG
   if($SOCKET_UPLOAD)
   {
      # assuming trtpd is currently splitting
      my $waitlong;
      while (!(-f "trtpd.log") && $waitlong < 5){sleep(2);$waitlong +=2;}
      print &PerlTranslate("Split.pl", "Split not required.\n") if ( $ENV{'ATTOLSTUDIO_VERBOSE'} );
      $used[$tdf]=(-f $TDFFILE);
      $used[$rio]=(-f $RIOFILE);
      $used[$tio]=$ATCMODE;
      $used[$tpf]=$ATPMODE;
      $used[$tqf]=$ATQMODE;

      my $memsum=MemproSummary($ATP_TPF_NAME) if($used[$tpf]);
      if ($LOGFILENAME) {
        open ( LOG, ">>$LOGFILENAME" ) or die &PerlTranslate("Split.pl", "Cannot open log file.\n");
        print  LOG "TDF $TDFFILE\n"      if ($used[$tdf]);
        print  LOG "TIO $ATC_TIO_NAME\n" if ($used[$tio]);
        print  LOG "RIO $RIOFILE\n"      if ($used[$rio]);
        print  LOG "TPF $ATP_TPF_NAME\n" if ($used[$tpf]);
        print  LOG "TQF $ATQ_TQF_NAME\n" if ($used[$tqf]);
        print  LOG "DUM $memsum\n" if ($memsum);
        close ( LOG );
      }
      FloatConvert($RIOFILE) if(($used[$rio]) && defined($Ini{RTRT_FLOAT_DUMP}));
      print &PerlTranslate("Split.pl", "External split done.\n");
      return 0;
   }
   elsif ( !$ATSMODE && !$ATL_MULTI_PROCESS && (($ATTMODE || $ATJMODE) && $ATT_ON_THE_FLY ) || ($ATCMODE && $ATC_ON_THE_FLY))
   {
      # assuming gui is currently splitting
      $UIriofile=$INTDIR."/atlout.rio"; #all rio line are written in this file

      sleep (3) ;
      #print "wait End Mark\n";
      my $waitlong=0;
      my $fsize;
      while (!(-f $INTDIR."/atlendtest.txt") && $waitlong < 15){
      	$fsize=(-s $UIriofile);sleep(2);$waitlong +=2 if($fsize==(-s $UIriofile));#print " $waitlong.$fsize ";
      }
      unlink($INTDIR."/atlendtest.txt");
      $used[$rio]=($ATUMODE || $ATVMODE);
      if(($ATUMODE || $ATVMODE) && (-f $UIriofile)) {
          # unknown line are rejected by the UI; So now split those rejected lines
          RenameFile($UIriofile,$RIOFILE);
      }else {
      	  print &PerlTranslate("Split.pl", "Split not required.\n") if ( $ENV{'ATTOLSTUDIO_VERBOSE'} );
          $used[$rio]=0;
      }
      $used[$tio]=1 if($ATCMODE && (-f $ATC_TIO_NAME));
      $used[$tdf]=(-f $TDFFILE);# this file is written at the beginning of the application
      #The split for TPF related information is done by SplitJvmpi for Java.
      $used[$tpf]=1 if($ATPMODE && ($TDP_LANGUAGE ne "JAVA"));
      $used[$tqf]=$ATQMODE;
      my $memsum=MemproSummary($ATP_TPF_NAME) if($used[$tpf]);
      print &PerlTranslate("Split.pl", "Result file looks empty\n") unless(-s $tracesfile);
      if ($LOGFILENAME) {
        open ( LOG, ">>$LOGFILENAME" ) or die &PerlTranslate("Split.pl", "Cannot open log file.\n");
        print  LOG "TDF $TDFFILE\n";
        print  LOG "TIO $ATC_TIO_NAME\n" if ($used[$tio]);
        print  LOG "TPF $ATP_TPF_NAME\n" if ($used[$tpf]);
        print  LOG "RIO $RIOFILE\n"      if ($used[$rio]);
        print  LOG "TQF $ATQ_TQF_NAME\n" if ($used[$tqf]);
        print  LOG "SPT $tracesfile\n";
        print  LOG "DUM $memsum\n" if ($memsum);
        close ( LOG );
      }
      FloatConvert($RIOFILE) if(($used[$rio]) && defined($Ini{RTRT_FLOAT_DUMP}));
      print &PerlTranslate("Split.pl", "On the fly split done.\n");
      return 0; ## if studio split

   }
   elsif ($filen == 1 && ($ATOMODE || $ATKMODE))
   # Optimize for these two ones
   {
     # No use to split file : rename only
     $output_files[$product] = $one_file;
     $used[$product] = 1;
     print &PerlTranslate("Split.pl", "Result file looks empty\n") unless(-s $tracesfile);
     RenameFile ($tracesfile, $output_files[$product]);
     open ( LOG, ">>$LOGFILENAME" ) or die &PerlTranslate("Split.pl", "Cannot open log file.\n");
     print  LOG "$log_codes[$product] $output_files[$product]\n";
     close( LOG );
     print &PerlTranslate("Split.pl", "Split done.\n");
     return 0;
   }

   ### now Do it

   if ($ATOMODE || $ATKMODE || $ATJMODE || $ATTMODE)
   {
     OpenDestFile ($tdf, $TDFFILE, $tdf_file_mode);
     my ($d,$n,$e) =SplitFileName($tracesfile);
     print { $handles[$tdf] } "NO \"system\" \"$n\"\nCI 0\n" if($tdf_file_mode eq "a");
   }

   if ($ATCMODE)
   {
     OpenDestFile ($tio, $ATC_TIO_NAME, "a");
   }

   if ($ATPMODE)
   {
     OpenDestFile ($tpf, $ATP_TPF_NAME, "a");
   }

   if ($ATQMODE)
   {
     OpenDestFile ($tqf, $ATQ_TQF_NAME, "a");
   }
   if ($ATUMODE || $ATVMODE || $ATSMODE)
   {
     OpenDestFile ($rio, $RIOFILE, "w");
   }
   my $retSplit=ExecSplit ($tracesfile, $warnings);
   for ($i = $tdf; $i < $undefined; $i++)
   {
     if ($opened[$i])
     {
       close ($handles[$i]);
     }
   }
   if ($warnings)
   {
     if (!$opened[$tdf] && $used[$tdf])
     {
       print &PerlTranslate("Split.pl", "Warning: TDF traces were ignored.\n");
     }
     if (!$opened[$tio] && $used[$tio])
     {
       print &PerlTranslate("Split.pl", "Warning: TIO traces were ignored.\n");
     }
     if (!$opened[$rio] && $used[$rio])
     {
       print &PerlTranslate("Split.pl", "Warning: RIO traces were ignored.\n");
     }
     if (!$opened[$tpf] && $used[$tpf])
     {
       print &PerlTranslate("Split.pl", "Warning: TPF traces were ignored.\n");
     }
     if (!$opened[$tqf] && $used[$tqf])
     {
       print &PerlTranslate("Split.pl", "Warning: TQF traces were ignored.\n");
     }
   }

   if ($retSplit != 0)
   {
     print &PerlTranslate("Split.pl", "Error while splitting traces file '%1'. Split aborted.\n\n", "%1 is the name of the file to be split", $tracesfile);
     return $retSplit;
   }

   open ( LOG, ">>$LOGFILENAME" ) or die &PerlTranslate("Split.pl", "Cannot open log file.\n") ;

   if ($ATUMODE || $ATVMODE || $ATSMODE)
   {
     CloseDestFile ($rio);
     print  LOG "$log_codes[$rio] $output_files[$rio]\n" ;
   }

   if ($ATOMODE || $ATKMODE || $ATJMODE || $ATTMODE)
   {
     CloseDestFile ($tdf);
     if($ATSMODE){
	print  LOG "TDA ".$output_files[$tdf]."\n" ;
     } else {
	print  LOG "$log_codes[$tdf] $output_files[$tdf]\n" ;
     }
   }

   if ($ATCMODE)
   {
     CloseDestFile ($tio);
     print  LOG "$log_codes[$tio] $output_files[$tio]\n" ;
   }

   if ($ATPMODE)
   {
     CloseDestFile ($tpf);
     {
        if($ATSMODE){
           print  LOG "TDA $output_files[$tpf]\n" ;
        } else {
	   print  LOG "$log_codes[$tpf] $output_files[$tpf]\n" ;
	}
        my $memsum=MemproSummary($output_files[$tpf]);
        print  LOG "DUM $memsum\n" if($memsum);
     }
   }

   if ($ATQMODE)
   {
     CloseDestFile ($tqf);
     if($ATSMODE){
           print  LOG "TDA $output_files[$tqf]\n" ;
     } else {
           print  LOG "$log_codes[$tqf] $output_files[$tqf]\n" ;
     }
   }
   if($ENV{'ATTOLSTUDIO_VERBOSE'})
   {
      unlink ("$tracesfile.bak");
      rename ($tracesfile,"$tracesfile.bak");
      print  LOG "DUM $tracesfile.bak\n" if($STUDIO_IDE);
   }
   else
   {
      unlink ($tracesfile);
   }
   close( LOG ) ;#unless($ATSMODE);
   FloatConvert($RIOFILE) if(($used[$rio]) && defined($Ini{RTRT_FLOAT_DUMP}));
   my $what;
   $what.='Cov ' if ($used[$tio]);
   $what.='Mem ' if ($used[$tpf]);
   $what.='Perf ' if ($used[$tqf]);
   $what.='Trace ' if ($used[$tdf]);
   print &PerlTranslate("Split.pl", "Traces file successfully split. $what\n");
   return 0;
}

sub MemproSummary
{
   my $file=shift;
   my $out=$file; $out=~s/\.tpf$//;
   my %ERR;
   my $x;
   open IN, "$file" || return 0;
   while(<IN>){
   	if(/^PE (\w+)/){
   	   my $e=$1;
   	   unless($e=~ m/CHK|FIU/){
   	      $ERR{$e}++ ;
   	      $x++;
   	   }
   	   #print "Mempro $e, $_, $ERR{$e}\n";
   	}
   }
   close IN;
   if($x) {
      open OUT, ">$out.atp.txt";
      print OUT "---   Memory errors Summary\n";
      foreach (sort keys %ERR){
   	print OUT "$_ found= $ERR{$_} times\n";
      }
      print OUT "Total Memory errors found=$x\n";
      close OUT;
      print "$x Memory Errors found\n";
      return "$out.atp.txt";
   }
   return 0;
}

sub splitAfterExec
{
	if ( $ATCMODE || $ATTMODE || $ATPMODE || $ATQMODE || $ATKMODE )
	{
	  # when socket uploader is used SplitTraces check created files and make the log
          #in Multi-process the spt file name has changed as xxxxx.pid.spt instead of xxxxx.spt
	       my $exeInstr=0;
		  if($ATL_MULTI_PROCESS){
			 my ($dir,$name,$ext) = SplitFileName($ATL_OUT_FILE);
	          	 sleep(2);#wait for all spt file closed
			 opendir(DIR,"$dir") || die &PerlTranslate("trtsplit.pl", "Error: unable to open directory %1.\n","%1 directory name",$dir);
			 while($f=readdir(DIR)) {
				if($f=~ /$name\..*\.$ext$/){
				SplitTraces ($dir.$f);
				$tdf_file_mode="a";
				}
			 }
			 closedir(DIR);
		  } else {
			SplitTraces ($ATL_OUT_FILE); # LOG are made inside SplitTraces
		  }
		  #---------------------------------------------------------------------
		  ## Coverage check ...
		  if ( $ATCMODE )
		  {
		      if ( ! $used[$tio] )
		      {
			  print &PerlTranslate("trtsplit.pl", "No Coverage results found.\n");
			  $exeInstr++;
		      }
		      atc_postpro($ATC_TIO_NAME,"") unless($TestRTCC); # no CIO in this node
		  }

		  #---------------------------------------------------------------------
		  ## Manage TDF Traces ...
		  if ( $ATTMODE )
		  { # No attsplit nor attloop on the fly
		      if ( $used[$tdf] )
		      {
			      # print $TDFFILE, "size=",(-s $TDFFILE),"\n";
			      if((-s $TDFFILE) > ($ATT_SPLIT_SIZE*1000)) {
				  # get the TSF file in the LOG to be used by the PostAttManage
				  readLogFile('s') unless(@TSFFILES);

				  #then split the big file
				  PostAttManage ($TDFFILE) if(@TSFFILES);
			      }
		      }
		      else
		      {
			  print &PerlTranslate("trtsplit.pl", "No Tracing results found.\n");
			  $exeInstr++;
		      }
		  } #ATTMODE==1

		  #---------------------------------------------------------------------
		  ## Memory Profiling check ...
		  if ( $ATPMODE )
		  {
		      if ( ! $used[$tpf] )
		      {
			  print &PerlTranslate("trtsplit.pl", "No Mempro results found.\n");
		      }
		  } #ATPMODE==1

		  #---------------------------------------------------------------------------
		  ## Performance Profiling check ...
		  if ( $ATQMODE )
		  {
		      if ( ! $used[$tqf] )
		      {
			  print &PerlTranslate("trtsplit.pl", "No Perfpro results found.\n");
			  $exeInstr++;
		      }
		  } #ATQMODE==1

		  #---------------------------------------------------------------------------
		if($exeInstr == 3) {
		  print "No results. Clean the project to instrument the application.\n";
		  return 1;
		}
	    } #ATCMODE==1 || ATTMODE==1 || ATPMODE==1 || ATQMODE==1 || $ATKMODE==1

return 0;
}

sub readLogFile
{
my $what=shift; #s=TSF+FDC, o=OBJECTS, x=XOB, b=OTSFILES
$what='s' unless($what);
my $d=".";
my $code;
my $f;
  if(open IN, $LOGFILENAME) {
      while(<IN>){
	chomp;
	if(/^DIR\s+(.*)$/) {$d=$1; next;}
	if(/^DUM\s/) {next;}
	if(/^(\w\w\w)\s+(.*)$/) {
	    $code=$1;$f=$2;
	    $f=$d.'/'.$f unless(-f $f);
	    if($code eq 'TSF') {if($what=~m/s/){ push(@TSFFILES,$f);} next;}
	    if($code eq 'FDC') {if($what=~m/s/){ push(@FDCFILES,$f);} next;}
	    if($code eq 'OBJ') {if($what=~m/o/){ push(@OBJECTS ,$f);} next;}
	    if($code eq 'OTS') {if($what=~m/b/){ push(@OTSFILES,$f);} next;}
	    if($code eq 'XOB') {if($what=~m/x/){ push(@XOB     ,$f);} next;}
	}
      }
      close IN;
  }
}

sub cleanLogFile
{
my @rmFiles=@_;
my $currentDir="";
 if(open IN, $LOGFILENAME) {
    my $tsf=( $ATTMODE || $ATPMODE || $ATQMODE || $ATKMODE );
    my %seen = ();
    foreach(@rmFiles){$seen{$_}++;}
    open OU, ">$LOGFILENAME.tmp" or die &PerlTranslate("trtsplit.pl", "cannot write the temp log file.\n");
    while(<IN>){
	if(/(SVS|INC|DEF|FLG|#OPT|#TGT)\s/){print OU;next}
	chomp;
	if(/(\w{3})\s+(.+)$/){
	   my $tk=$1;
	   if(($currentDir=="") && ($tk eq 'DIR')) {
			$currentDir=$2;
	   }
	   my $pt=absolutePath($2,$currentDir);
	   unless( $seen{$pt}++){
		if(($tk eq 'DUM') && !($KEEP)) {
			# unlink absolute and relative files
			if (-f $pt) {
				unlink($pt);
#			} else {
#				unlink($currentDir."/".$2);
			}
		}
		elsif(($tk eq 'TDF') && !(-f $pt)){} #remove the line if the file has been splitted
		else {print OU "$tk $2\n" ;}
	   }
	} else {
	    print "unknown line in log file $_\n";
	}
   }
   close IN;
   close OU;
   rename($LOGFILENAME.'.tmp',$LOGFILENAME);
 } else {
	&PerlTranslate("trtsplit.pl", "No result log found.\n");
 }
}

sub ParseAtsRioFile #($)
{
   my $riofile = shift;
   SplitTraces ($riofile) and return 1;
   rename ("$riofile.date", $riofile) or return 1;
   return 0;
}

sub FloatConvert #($RIOFILE)
{
    my $file=shift;
    my $exe;
    my $PATHSEP='/';
    if($^O=~/win32/i) {
    	$exe='.exe' ;
    	$PATHSEP='\\';
    }
    if(-f $file){
	if(-f "$ENV{ATLTGT}/cmd/extrdump$exe") {
		$exe=$ENV{ATLTGT}.$PATHSEP.'cmd'.$PATHSEP."extrdump".$exe
	} else {
		$exe="extrdumpieee".$exe;
	}
	SystemP("$exe $file $file.tmp");
	rename("$file.tmp",$file);
    }
}


1;
